@@ -79,7 +79,9 @@ class MenusModel(QAbstractListModel):
     def __init__(self,menus=None, parent=None):
         super(MenusModel, self).__init__(parent)
         self.menus=menus
-
+        self.unread_counts = {}
+        for attr in Utils.UNREAD_ATT_COUNTS:
+            self.unread_counts[attr] = 0
 
     def rowCount(self,parent=None):
         return len(self.menus)
@@ -93,12 +95,59 @@ class MenusModel(QAbstractListModel):
             menu=self.menus[index.row()]["name"]
 #            html=self.makeMenuHtml(menu)
             return menu
+            
+        if (role == Utils.ROLE_UNREAD):
+            #print "<Utils.ROLE_UNREAD"
+           #print self.get_unread_counts(index.row())
+            #print "Utils.ROLE_UNREAD>"
+            return self.get_unread_counts(index.row())
+            
         if (role==Utils.ROLE_AVATAR):
             return self.menus[index.row()]["icon"]
         else:
             return self.menus[index.row()]["value"]
+    def get_unread_counts(self, menu_row):  
+        if menu_row == 1:
+            #print "get_unread_counts: mentions"
+            return self.unread_counts["mentions"]
+        elif menu_row == 2:
 
+            #print "get_unread_counts: comments"
+            return self.unread_counts["comments"]
+        else:
+            #print "===NA==="
+            return 0
+            
+    def set_unread_counts(self, unread_counts):
+        try:
+            for attr in Utils.UNREAD_ATT_COUNTS:
+                self.unread_counts[attr] = unread_counts[attr]
+        except:
+            self.unread_counts[attr] = 0
+            
+    def clear_unread_count(self, optype):
+        if optype == Utils.TIMELINE_TYPE_MENTIONS:
+            self.unread_counts["mentions"] = 0
+            #print "clear_unread_count: mentions"
+        elif optype == Utils.TIMELINE_TYPE_COMMENTS:
+            self.unread_counts["comments"] = 0
+            #print "clear_unread_count: comments"
+        else:
+            print "clear_unread_count: not support"
+            
+    def need_clear_unread_count(self, optype):
+        if optype == Utils.TIMELINE_TYPE_MENTIONS and self.unread_counts["mentions"] > 0:
+            #print "need_clear_unread_count: mentions need clear"
+            return True
+        elif optype == Utils.TIMELINE_TYPE_COMMENTS and self.unread_counts["comments"] > 0:
+            #print "clear_unread_count: comments need clear"
+            return True
+        else:
+            #print "clear_unread_count: not support"
+            return False
 
+            
+         
 class StatusModel(QAbstractListModel):
     def __init__(self, statuses=None, parent=None):
         super(StatusModel, self).__init__(parent)
@@ -191,12 +240,8 @@ class StatusModel(QAbstractListModel):
             rt=status["retweeted_status"]
         except KeyError,ke:
             return
-	
+
         if rt!=None:
-        
-	    #print "debug rt:"
-	    #print rt
-	
             rtUser=rt["user"]
             rtName=rtUser["name"]
             rtScreenName=rtUser["screen_name"]
